<?php
define('SOFORT_URL', 'https://www.sofort.com/payment/start');

class appSofort {

    private $config = array();

    public function __construct() {
        $this->config = stPaymentType::getConfiguration(__CLASS__);
    }

    public function __call($method, $arguments) {
        return stPaymentType::call($method, $this->config);
    }

    public function checkPaymentConfiguration() {
        if (!$this->config['user_id'] || !$this->config['project_id'] || !$this->config['api_key']) return false;
        if (SF_APP == 'frontend') {
            $currencies = array('EUR', 'GBP', 'CHF', 'PLN', 'HUF', 'CZK');
            if (!in_array(stCurrency::getInstance(sfContext::getInstance())->get()->getShortcut(), $currencies)) return false;
        }
        return true;
    }

    public function getPaymentUrl(Order $order)
    {
        $sf_context = sfContext::getInstance();
        $controller = $sf_context->getController();
        $i18n = $sf_context->getI18N();

        $api = new Sofortueberweisung($this->getConfigKey());

        $api->setAmount($order->getUnpaidAmount());
        $api->setCurrencyCode($order->getOrderCurrency()->getShortcut());
        $api->setLanguageCode($this->getLanguageCode($order));

        $api->setReason(sfContext::getInstance()->getRequest()->getHost(), $i18n->__("Zamówienie nr", null, 'stOrder').' '.$order->getNumber());
        $api->setSuccessUrl($controller->genUrl('@appSofortPlugin?action=returnSuccess', true), true);
        $api->setAbortUrl($controller->genUrl('@appSofortPlugin?action=returnFail&id='.$order->getId().'&hash='.$order->getHashCode(), true));
        $api->setNotificationUrl($controller->genUrl('@appSofortPlugin?action=statusReport&id='.$order->getId().'&hash='.$order->getHashCode(), true));

        $api->sendRequest();

        if($api->isError()) 
        {
            throw new Exception($api->getError());  
        } 
        else 
        {
            $url = $api->getPaymentUrl();
        }

        return $url;
    }

    public function verifyTransaction($body)
    {
        // enter your configuration key – you only can create a new configuration key by creating
        // a new Gateway project in your account at sofort.com
        $configkey = $this->getConfigKey();

        // read the notification from php://input  (http://php.net/manual/en/wrappers.php.php)
        // this class should be used as a callback function
        $SofortLib_Notification = new SofortLibNotification();

        $TestNotification = $SofortLib_Notification->getNotification($body);

        // echo $SofortLib_Notification->getTransactionId();
        // echo '<br />';
        // echo $SofortLib_Notification->getTime();
        // echo '<br />';

        $SofortLibTransactionData = new SofortLibTransactionData($configkey);

        // If SofortLib_Notification returns a transaction_id:
        $SofortLibTransactionData->addTransaction($TestNotification);

        //$SofortLibTransactionData->addTransaction(array('00907-01222-50F00112-D86E', '00907-01222-50EFFC79-7E33'));
        //$SofortLibTransactionData->addTransaction(array('00907-37660-51D2CD5E-8182'));
        //$SofortLibTransactionData->addTransaction('00907-01222-51ADD8C9-86C8');

        // By default without setter Api version 1.0 will be used due to backward compatibility, please
        // set ApiVersion to latest version. Please note that the response might have a different structure and values
        // For more details please see our Api documentation on https://www.sofort.com/integrationCenter-ger-DE/integration/API-SDK/
        $SofortLibTransactionData->setApiVersion('2.0');

        //$SofortLibTransactionData->setTime('2012-11-14T18:00+02:00', '2012-12-13T00:00+02:00');
        //$SofortLibTransactionData->setNumber(5, 1);

        $SofortLibTransactionData->sendRequest();

        if ($SofortLibTransactionData->isError()) 
        {
            throw new Exception($SofortLibTransactionData->getError());
        } 
         
        return $SofortLibTransactionData;
    }

    protected function getConfigKey()
    {
        return $this->config['user_id'].':'.$this->config['project_id'].':'.$this->config['api_key'];        
    }

    protected function getLanguageCode(Order $order)
    {
        $language = $order->getClientCulture();

        if ($language == 'pl_PL')
        {
            $language = 'PL';
        }
        elseif ($language == 'en_US')
        {
            $language = 'EN';
        }

        return strtoupper($language);
    }
}