<?php
class appSofortBackendActions extends stAdminGeneratorActions{
    
    public function executeStart() {
        $config = stConfig::getInstance($this->getContext());
        
        if ($config->get('user_id')) $this->redirect('appSofortBackend/index');
        else $this->redirect('appSofortBackend/information');
    }
    
    public function executeInformation() {
        $this->menu_items = $this->getMenuItems();
        $this->webRequest = new stWebRequest();
        $this->config = stConfig::getInstance($this->getContext());
        
        $c = new Criteria();
        $c->add(MailAccountPeer::IS_DEFAULT, true);
        $mailAccount = MailAccountPeer::doSelectOne($c);
        
        $this->mail = null;
        if (is_object($mailAccount)) {
            $this->mail = $mailAccount->getEmail();
        }
        
        list($this->language, $x) = explode('_', strtoupper($this->getUser()->getCulture()));
    }

    public function executeIndex() {
        $this->menu_items = $this->getMenuItems();
        $this->config = stConfig::getInstance('appSofortBackend');
        $this->labels = $this->getLabels();

        if ($this->getRequest()->getMethod() == sfRequest::POST) {
            $this->config->setFromRequest('config');
            $this->config->save();
            $this->setFlash('notice', 'Twoje zmiany zostały zapisane');

            return $this->redirect('@appSofortPlugin?action=index');
        }
        $i18n = $this->getContext()->getI18N();

        $this->getBreadcrumbs()->add($i18n->__('Konfiguracja', null, 'stAdminGeneratorPlugin'));
    }

    public function validateIndex()
    {
        $request = $this->getRequest();

        if ($request->getMethod() == sfRequest::POST) 
        {
            $i18n = $this->getContext()->getI18N();
            $config = $request->getParameter('config');

            if (empty($config['user_id']))
            {
                $request->setError('config{user_id}', $i18n->__('Proszę uzupełnić pole'));
            }

            if (empty($config['project_id']))
            {
                $request->setError('config{project_id}', $i18n->__('Proszę uzupełnić pole'));
            }

            if (empty($config['api_key']))
            {
                $request->setError('config{api_key}', $i18n->__('Proszę uzupełnić pole'));
            }

            if (!$request->hasErrors())
            {
                $controller = $this->getContext()->getController();
                $configkey = $config['user_id'].':'.$config['project_id'].':'.$config['api_key'];
                $api = new Sofortueberweisung($configkey);

                $api->setAmount(100);
                $api->setCurrencyCode('EUR');
                $api->setLanguageCode($this->getUser()->getCulture() == 'pl_PL' ? 'PL' : 'EN');

                $api->setReason(sfContext::getInstance()->getRequest()->getHost(), 'validate-'.uniqid());
                $url = 'http://'.sfContext::getInstance()->getRequest()->getHost();
                $api->setSuccessUrl($url);
                $api->setAbortUrl($url);
                $api->setNotificationUrl($url);

                $api->sendRequest();

                if($api->isError()) 
                {
                    $request->setError('config{api}', $i18n->__('Błędna konfiguracja płatności - sprawdź dane ('.$api->getError().')'));
                }
                 
            }
        }

        return !$request->hasErrors();
    }

    public function handleErrorIndex() 
    {
        $this->menu_items = $this->getMenuItems();
        $this->webRequest = new stWebRequest();
        $this->config = stConfig::getInstance($this->getContext());
        $this->config->setFromRequest('config');
        $this->labels = $this->getLabels();

        $i18n = $this->getContext()->getI18N();

        $this->getBreadcrumbs()->add($i18n->__('Konfiguracja', null, 'stAdminGeneratorPlugin'));

        return sfView::SUCCESS;
    }
    
    protected function getMenuItems() 
    {
        $i18n = $this->getContext()->getI18N();
        return array(
                      'appSofortBackend/information' => $i18n->__('Informacje'),
                      'appSofortBackend/index' => $i18n->__('Konfiguracja'));
    }

    protected function getLabels()
    {
        return array(
            'config{user_id}' => $this->getContext()->getI18n()->__('Numer klienta'),
            'config{project_id}' => $this->getContext()->getI18n()->__('ID projektu'),
            'config{api_key}' => $this->getContext()->getI18n()->__('Klucz API'),
            'config{api}' => $this->getContext()->getI18n()->__('Sofort')
        );
    }

    protected function getBreadcrumbs(){
        
        if (null === $this->breadcrumbs){
            $i18n = $this->getContext()->getI18N();
            $this->breadcrumbs = parent::getBreadcrumbs();
            $this->breadcrumbs->add($i18n->__('Klarna'), '@appSofortPlugin');
        }

        return $this->breadcrumbs;
    }
}
